module.exports = function(grunt){
    var jsonPath = 'json/**/*.json';
    var configPath = 'config/LibConfig.js';
    var configSaasPath = 'config/LibConfig_server.js';
    var utilPath = 'js/Util/**/*.js';
    var servicePath = 'js/Service/**/*.js';
    var controllerPath = 'js/Controller/**/*.js';
    var listenerPath = 'js/Listener/**/*.js';

    grunt.initConfig({

        // grunt-contrib-concat
        concat: {
            zh: {
                options: {
                    process: function(src, filePath){
                        return '\n' + '// FILE: ' + filePath + '\n' + src;
                    }
                },
                src: [
                    configPath, utilPath, servicePath, controllerPath, listenerPath
                ],
                dest: 'dist/main.js'
            }
        },

        // grunt-contrib-jshint
        jshint: {
            all: ['Gruntfile.js', './js/Util/**/*.js', './js/Service/**/*.js', './js/Controller/**/*.js']
        },

        // grunt-contrib-uglify
        uglify: {
            options: {
                mangle: false,
                compress: false,
                report: 'min',
                banner: '/*! <%= grunt.template.today("dd-mm-yyyy") %> */\n'
            },
            dist: {
                files: {
                    'dist/main.min.js': [configPath, utilPath, servicePath, controllerPath, listenerPath]
                }
            }
        },

        // grunt-contrib-watch
        watch: {
            pivotal: {
                files: [configPath, utilPath, servicePath, controllerPath, listenerPath],
                tasks: ['jshint', 'uglify', 'concat']
            }
        },
        bump: {
            options: {
                files: ['bower.json'],
                updateConfigs: [],
                commit: true,
                commitMessage: 'Release v%VERSION%',
                commitFiles: ['bower.json'],
                createTag: true,
                tagName: '%VERSION%',
                tagMessage: 'Version %VERSION%',
                push: true,
                pushTo: 'origin',
                gitDescribeOptions: '--tags --always --abbrev=1 --dirty=-d',
                globalReplace: false,
                prereleaseName: false,
                metadata: '',
                regExp: false
            }
        }
    });

    grunt.loadNpmTasks('grunt-contrib-jshint');
    grunt.loadNpmTasks('grunt-contrib-uglify');
    grunt.loadNpmTasks('grunt-contrib-concat');
    grunt.loadNpmTasks('grunt-contrib-watch');
    grunt.loadNpmTasks('grunt-bump');

    grunt.registerTask('default', ['uglify', 'concat']);
    grunt.registerTask('basic', ['concat']);
};